@@ -3,11 +3,11 @@ import urllib2
 import json
 
 class Logger:
-  version = '1.0.0'
+  version = '1.0.1'
   
   api_key = None
   
-  base_uri = 'http://getlogger.com/logger/%s/'
+  base_uri = 'https://getlogger.com/logger/%s/'
   
   @staticmethod
   def init(api_key):
